@@ -5,9 +5,12 @@ from braintree.credit_card_gateway import CreditCardGateway
 from braintree.customer_gateway import CustomerGateway
 from braintree.discount_gateway import DiscountGateway
 from braintree.merchant_account_gateway import MerchantAccountGateway
+from braintree.paypal_account_gateway import PayPalAccountGateway
+from braintree.payment_method_gateway import PaymentMethodGateway
 from braintree.plan_gateway import PlanGateway
 from braintree.settlement_batch_summary_gateway import SettlementBatchSummaryGateway
 from braintree.subscription_gateway import SubscriptionGateway
+from braintree.testing_gateway import TestingGateway
 from braintree.transaction_gateway import TransactionGateway
 from braintree.transparent_redirect_gateway import TransparentRedirectGateway
 from braintree.credit_card_verification_gateway import CreditCardVerificationGateway
@@ -32,3 +35,6 @@ class BraintreeGateway(object):
         self.verification = CreditCardVerificationGateway(self)
         self.webhook_notification = WebhookNotificationGateway(self)
         self.webhook_testing = WebhookTestingGateway(self)
+        self.payment_method = PaymentMethodGateway(self)
+        self.paypal_account = PayPalAccountGateway(self)
+        self.testing = TestingGateway(self)
