@@ -95,7 +95,7 @@ class Subscription(Resource):
             "trial_duration_unit",
             "trial_period",
             {
-                "descriptor": [ "name", "phone" ]
+                "descriptor": [ "name", "phone", "url" ]
             },
             {
                 "options": [
@@ -190,7 +190,7 @@ class Subscription(Resource):
             "plan_id",
             "price",
             {
-                "descriptor": [ "name", "phone" ]
+                "descriptor": [ "name", "phone", "url" ]
             },
             {
                 "options": [ "prorate_charges", "replace_all_add_ons_and_discounts", "revert_subscription_on_proration_failure" ]
