@@ -43,6 +43,9 @@ class TestSubscription(unittest.TestCase):
         self.assertEquals(date, type(subscription.billing_period_end_date))
         self.assertEquals(date, type(subscription.paid_through_date))
 
+        self.assertEquals(datetime, type(subscription.created_at))
+        self.assertEquals(datetime, type(subscription.updated_at))
+        
         self.assertEquals(1, subscription.current_billing_cycle)
         self.assertEquals(0, subscription.failure_count)
         self.assertEquals(self.credit_card.token, subscription.payment_method_token)
@@ -470,13 +473,14 @@ class TestSubscription(unittest.TestCase):
             result.errors.for_object("subscription").for_object("add_ons").for_object("update").for_index(1).on("quantity")[0].code
         )
 
-    def test_descriptors_accepts_name_and_phone(self):
+    def test_descriptors_accepts_name_phone_and_url(self):
         result = Subscription.create({
             "payment_method_token": self.credit_card.token,
             "plan_id": TestHelper.trialless_plan["id"],
             "descriptor": {
                 "name": "123*123456789012345678",
-                "phone": "3334445555"
+                "phone": "3334445555",
+                "url": "ebay.com"
             }
         })
 
@@ -488,6 +492,7 @@ class TestSubscription(unittest.TestCase):
         transaction = subscription.transactions[0]
         self.assertEquals("123*123456789012345678", transaction.descriptor.name)
         self.assertEquals("3334445555", transaction.descriptor.phone)
+        self.assertEquals("ebay.com", transaction.descriptor.url)
 
     def test_descriptors_has_validation_errors_if_format_is_invalid(self):
         result = Transaction.sale({
