@@ -7,35 +7,35 @@ class TestTransaction(unittest.TestCase):
         try:
             Transaction.clone_transaction("an id", {"bad_key": "value"})
             self.assertTrue(False)
-        except KeyError, e:
+        except KeyError as e:
             self.assertEquals("'Invalid keys: bad_key'", str(e))
 
     def test_sale_raises_exception_with_bad_keys(self):
         try:
             Transaction.sale({"bad_key": "value"})
             self.assertTrue(False)
-        except KeyError, e:
+        except KeyError as e:
             self.assertEquals("'Invalid keys: bad_key'", str(e))
 
     def test_sale_raises_exception_with_nested_bad_keys(self):
         try:
             Transaction.sale({"credit_card": {"bad_key": "value"}})
             self.assertTrue(False)
-        except KeyError, e:
+        except KeyError as e:
             self.assertEquals("'Invalid keys: credit_card[bad_key]'", str(e))
 
     def test_tr_data_for_sale_raises_error_with_bad_keys(self):
         try:
             Transaction.tr_data_for_sale({"bad_key": "value"}, "http://example.com")
             self.assertTrue(False)
-        except KeyError, e:
+        except KeyError as e:
             self.assertEquals("'Invalid keys: bad_key'", str(e))
 
     def test_finding_empty_id_raises_not_found_exception(self):
         try:
             Transaction.find(" ")
             self.assertTrue(False)
-        except NotFoundError, e:
+        except NotFoundError as e:
             self.assertTrue(True)
 
     def test_constructor_includes_disbursement_information(self):
